.. currentmodule:: abjad.tools.scoretools

fill_measures_in_expr_with_time_signature_denominator_notes
===========================================================

.. autofunction:: fill_measures_in_expr_with_time_signature_denominator_notes
